SHMouseEventData class final

Mouse/wheel event data.

event_type: 0=mouse-down, 1=mouse-up, 2=mouse-move, 3=mouse-wheel button: None=-1, Left=0, Middle=1, Right=2, Back=3, Forward=4, Unknown=99. For mouse-wheel: 0=Vertical, 1=Horizontal. flag: wheel direction (1=Up/Right, -1=Down/Left; 0 for non-wheel events).

Sentinel INVALID_COORDINATE (-99999) applies to x/y on Linux Wayland.

Inheritance
Implemented types
Available extensions

Constructors

SHMouseEventData()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
button int
getter/setter pair
event_type int
getter/setter pair
flag int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
getter/setter pair
y int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited