SHPositionLevel enum

Position level identifiers.

Inheritance
Available extensions

Values

SH_POS_LEVEL_NONE → const SHPositionLevel
const SHPositionLevel(0)
SH_POS_LEVEL_MOUSE_SINGLE → const SHPositionLevel
const SHPositionLevel(1)
SH_POS_LEVEL_MOUSE_DUAL → const SHPositionLevel
const SHPositionLevel(2)
SH_POS_LEVEL_SEL_FULL → const SHPositionLevel
const SHPositionLevel(3)
SH_POS_LEVEL_SEL_DETAILED → const SHPositionLevel
const SHPositionLevel(4)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) SHPositionLevel

Constants

values → const List<SHPositionLevel>
A constant List of the values in this enum, in order of their declaration.