SHSelectionConfig class final

Configuration for text selection monitoring. All fields are optional — pass 0 for defaults.

Inheritance
Implemented types
Available extensions

Constructors

SHSelectionConfig()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
clipboard_mode int
FilterMode: 0=Default, 1=IncludeList, 2=ExcludeList
getter/setter pair
debug int
1=enable diagnostic logging
getter/setter pair
enable_clipboard int
1=enable clipboard fallback (default: 1)
getter/setter pair
enable_mouse_move int
1=enable high-CPU mouse-move events
getter/setter pair
global_filter_mode int
FilterMode for global program filter
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection_passive_mode int
1=require manual trigger for selection
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited