SHSelectionMethod enum
Selection method identifiers.
Values
- SH_METHOD_NONE → const SHSelectionMethod
-
const SHSelectionMethod(0) - SH_METHOD_UIA → const SHSelectionMethod
-
const SHSelectionMethod(1) - SH_METHOD_FOCUSCTL → const SHSelectionMethod
-
Removed upstream, kept for alignment.
const SHSelectionMethod(2) - SH_METHOD_ACCESSIBLE → const SHSelectionMethod
-
const SHSelectionMethod(3) - SH_METHOD_AXAPI → const SHSelectionMethod
-
const SHSelectionMethod(11) - SH_METHOD_ATSPI → const SHSelectionMethod
-
@reserved AT-SPI method reserved for future use.
const SHSelectionMethod(21) - SH_METHOD_PRIMARY → const SHSelectionMethod
-
const SHSelectionMethod(22) - SH_METHOD_CLIPBOARD → const SHSelectionMethod
-
const SHSelectionMethod(99)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → SHSelectionMethod
Constants
-
values
→ const List<
SHSelectionMethod> - A constant List of the values in this enum, in order of their declaration.