SHKeyboardEventData class final
Keyboard event data.
uni_key: MDN KeyboardEvent.key value (UTF-8, NUL-terminated). Library-owned, valid only during callback. vk_code: Platform-specific virtual key code. Windows=VK_, macOS=kVK_, Linux=KEY_* from linux/input-event-codes.h. sys: Non-zero if Alt/Ctrl/Win/Cmd/Fn modifier pressed simultaneously. flags: Additional platform-specific flags (Linux: modifier bitmask).
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - flags ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sys ↔ int
-
getter/setter pair
-
uni_key
↔ Pointer<
Char> -
getter/setter pair
- vk_code ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited