SHSelectionData class final

Text selection data returned via callback or sh_get_current_selection.

All const char* fields are owned by the library. In callbacks, they are valid only for the duration of the callback. In sh_get_current_selection, they are valid until the next call or until sh_free_selection_data.

Sentinel value for unavailable coordinates: -99999 (INVALID_COORDINATE). On Linux, startTop/startBottom/endTop/endBottom are always INVALID_COORDINATE. On Linux Wayland, mouseStart/mouseEnd may also be INVALID_COORDINATE.

Inheritance
Implemented types
Available extensions

Constructors

SHSelectionData()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
end_bottom SHPoint
Last paragraph bottom-right (screen pixels).
getter/setter pair
end_top SHPoint
Last paragraph top-right (screen pixels).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
is_fullscreen int
Fullscreen state of the source window (macOS only, 0=unknown/no, 1=yes).
getter/setter pair
method int
Selection method (enum SHSelectionMethod).
getter/setter pair
mouse_end SHPoint
Mouse position when selection ended (screen pixels).
getter/setter pair
mouse_start SHPoint
Mouse position when selection started (screen pixels).
getter/setter pair
pos_level int
Position level (enum SHPositionLevel).
getter/setter pair
program_name Pointer<Char>
Program name that triggered the selection (UTF-8, NUL-terminated).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start_bottom SHPoint
First paragraph bottom-left (screen pixels).
getter/setter pair
start_top SHPoint
First paragraph top-left (screen pixels).
getter/setter pair
text Pointer<Char>
Selected text content (UTF-8, NUL-terminated).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited